@@ -18,7 +18,7 @@ class CookieManagerAPI(object):
     A CookieManager acts like a ``dict``, so you can access the value of a
     cookie through the [] operator, passing the cookie identifier:
 
-        >>> cookie_manager.add({ 'name' : 'Tony' })
+        >>> cookie_manager.add({'name': 'Tony'})
         >>> assert cookie_manager['name'] == 'Tony'
     """
     __metaclass__ = InheritedDocs
@@ -32,7 +32,7 @@ class CookieManagerAPI(object):
 
         Example of use:
 
-            >>> cookie.add({ 'name' : 'Tony' })
+            >>> cookie_manager.add({'name': 'Tony'})
         """
         raise NotImplementedError
 
@@ -45,10 +45,22 @@ class CookieManagerAPI(object):
 
         Examples:
 
-            >>> cookie.delete() # deletes all cookies
-            >>> cookie.delete('name', 'birthday',
-                              'favorite_color') # deletes these three cookies
-            >>> cookie.delete('name') # deletes one cookie
+            >>> cookie_manager.delete() # deletes all cookies
+            >>> cookie_manager.delete('name', 'birthday',
+                                      'favorite_color') # deletes these three cookies
+            >>> cookie_manager.delete('name') # deletes one cookie
+        """
+        raise NotImplementedError
+
+    def all(self):
+        """
+        Returns all of the cookies.
+
+        Examples:
+
+            >>> cookie_manager.add({'name': 'Tony'})
+            >>> cookie_manager.all()
+            [{'name': 'Tony'}]
         """
         raise NotImplementedError
 
