@@ -4,7 +4,6 @@
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
-from __future__ import with_statement
 import re
 
 from lxml.cssselect import CSSSelector
@@ -151,7 +150,7 @@ class ZopeTestBrowser(DriverAPI):
                 control = self._browser.getControl(name=name, index=index)
                 elements.append(control)
                 index += 1
-            except IndexError:
+            except LookupError:
                 break
         return ElementList([ZopeTestBrowserControlElement(element, self) for element in elements], find_by="name", query=name)
 
@@ -165,7 +164,7 @@ class ZopeTestBrowser(DriverAPI):
         return self._find_links_by_xpath("//a[contains(@href, '%s')]" % partial_href)
 
     def find_link_by_partial_text(self, partial_text):
-        return self._find_links_by_xpath("//a[contains(text(), '%s')]" % partial_text)
+        return self._find_links_by_xpath("//a[contains(normalize-space(.), '%s')]" % partial_text)
 
     def fill(self, name, value):
         self.find_by_name(name=name).first._control.value = value
@@ -174,9 +173,7 @@ class ZopeTestBrowser(DriverAPI):
         for name, value in field_values.items():
             element = self.find_by_name(name)
             control = element.first._control
-            if control.type in ['text', 'textarea', 'password']:
-                control.value = value
-            elif control.type == 'checkbox':
+            if control.type == 'checkbox':
                 if value:
                     control.value = control.options
                 else:
@@ -185,6 +182,9 @@ class ZopeTestBrowser(DriverAPI):
                 control.value = [option for option in control.options if option == value]
             elif control.type == 'select':
                 control.value = [value]
+            else:
+                # text, textarea, password, tel
+                control.value = value
 
     def choose(self, name, value):
         control = self._browser.getControl(name=name)
